# Invpy package v0.0.1

- Package that includes several methods to compute statistical translation non-invariance of primarly, but not limitted to, scalar
cosmological fields.

## Packages needed

- To use 'invpy', you will need only 'numpy' as its base package. 

